aboutsummaryrefslogtreecommitdiff
path: root/include/apos/syscalls.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/apos/syscalls.h')
-rw-r--r--include/apos/syscalls.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/apos/syscalls.h b/include/apos/syscalls.h
index 9346da3..e7b1cd5 100644
--- a/include/apos/syscalls.h
+++ b/include/apos/syscalls.h
@@ -25,7 +25,8 @@ enum {
* structure of the OS, but these following syscalls are probably
* required */
SYS_IPC_SERVER, /* inform kernel that process should be treated as a server */
- SYS_IPC_REQ, /* IPC request to server */
+ SYS_IPC_REQ_PROC, /* IPC request to server on behalf of process */
+ SYS_IPC_REQ_THREAD, /* IPC request to server on behalf of thread */
SYS_IPC_RESP, /* IPC response from server */
/* process management */